function xM = genmultiPoisson(parV,n)
% xM = genmultiPoisson(parV,n)
% GENMULTIPOISSON generates a sample 'xM' of size 'n x m' from the
% multivariate Poisson distribution of dimension m, given the parameters in
% vector 'parV' of length m+1. 
% The implementation e.g. for m=2 is as follows
%   xM(i,1) = y(i,1) + y(i,3)
%   xM(i,2) = y(i,2) + y(i,3)
% where y(i,j), j=1,2,3 are independent Poisson variates with parameters
% lambda_1 - phi, lambda_2 - phi, and phi, and these are given in input as 
% parV = [lambda_1, lambda_2, phi].
%
%     Copyright (C) 2015 Dimitris Kugiumtzis
%
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
%
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
%
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
if nargin==1
    n=1;
end
parV = parV(:);
m = length(parV)-1;
xM = NaN(n,m);
lambdaV = [parV(1:m)-parV(m+1); parV(m+1)]';
if any(lambdaV<0)
    fprintf('*** Error: Only NaN is returned because at least one of the Poisson parameters becomes negative.***');
else
    yM = NaN(n,m+1);
    for j=1:m+1
        yM(:,j) = poissrnd(lambdaV(j),n,1);
    end
    for j=1:m
        xM(:,j) = yM(:,j) + yM(:,m+1);
    end
end
